import React from 'react';
import './Instructions.css';

interface InstructionsProps {
  visible: boolean;
  onClose: () => void;
}

export const Instructions: React.FC<InstructionsProps> = ({ visible, onClose }) => {
  if (!visible) return null;

  return (
    <div className="instructions-overlay" onClick={onClose}>
      <div className="instructions-panel" onClick={e => e.stopPropagation()}>
        <div className="instructions-header">
          <h2>Welcome to ✨ ZoomAccel ✨!</h2>
        </div>
        
        <div className="instructions-content">
          <p>
            This is a simulation that measures target acquisition performance with different zoom acceleration curves.
          </p>
          
          <ul>
            <li>
              Click the green targets as quickly and accurately as possible
            </li>
            <li>
              Use <span className="keyboard-shortcut">Ctrl + Scroll</span> or <span className="keyboard-shortcut">⌘ + Scroll</span> to zoom
            </li>
            <li>
              Click and drag to pan the view
            </li>
            <li>
              Toggle zoom acceleration and customize the curve in Settings <span className="keyboard-shortcut">⚙️</span>
            </li>
            <li>
              View your performance history and export results using the History panel <span className="keyboard-shortcut">📊</span>
            </li>
          </ul>

          <p>
            Try different acceleration curves to find what works best for you!
          </p>
        </div>

        <div className="instructions-footer">
          <button className="got-it-button" onClick={onClose}>
            Got it!
          </button>
        </div>
      </div>
    </div>
  );
}; 