import { Target, CONSTANTS } from '../types';

export const generateTargets = () => {
	const newTargets: Target[] = [];
	const PADDING = CONSTANTS.TARGET_MAX_RADIUS * 2;
  
	// Calculate width segments to distribute targets evenly
	const segmentWidth = (CONSTANTS.VIRTUAL_CANVAS_SIZE - PADDING * 2) / Math.sqrt(CONSTANTS.TARGET_COUNT);
	const numColumns = Math.ceil(Math.sqrt(CONSTANTS.TARGET_COUNT));
  
	for (let i = 0; i < CONSTANTS.TARGET_COUNT; i++) {
		let validPosition = false;
		let newTarget: Target;

		// Calculate the grid position
		const column = i % numColumns;
		const row = Math.floor(i / numColumns);
    
		while (!validPosition) {
			const radius = CONSTANTS.TARGET_MIN_RADIUS + 
				Math.random() * (CONSTANTS.TARGET_MAX_RADIUS - CONSTANTS.TARGET_MIN_RADIUS);
        
			// Base position from grid
			const baseX = PADDING + column * segmentWidth;
			const baseY = PADDING + row * segmentWidth;
        
			// Add some randomness within the cell
			const x = baseX + Math.random() * (segmentWidth - radius * 2);
			const y = baseY + Math.random() * (segmentWidth - radius * 2);
        
			newTarget = { x, y, radius };
			validPosition = true;

			// Check for overlaps
			for (const existing of newTargets) {
				const distance = Math.hypot(existing.x - x, existing.y - y);
				if (distance < (existing.radius + radius) * 2) {
					validPosition = false;
					break;
				}
			}
		}
		newTargets.push(newTarget!);
	}
	return newTargets;
};

export const getRandomTarget = (currentTarget: number | null, maxTargets: number): number => {
	let newTarget: number;
	do {
		newTarget = Math.floor(Math.random() * maxTargets);
	} while (newTarget === currentTarget);
	return newTarget;
};
